# Echo Datastore Entities (<a href="https://echomobi.github.io/echo-datastore-entities/" target="_blank">docs</a>)

[![CircleCI](https://circleci.com/gh/echomobi/echo-datastore-entities.svg?style=svg)](https://circleci.com/gh/echomobi/echo-datastore-entities)
[![codecov](https://codecov.io/gh/echomobi/echo-datastore-entities/branch/master/graph/badge.svg)](https://codecov.io/gh/echomobi/echo-datastore-entities)

Client library for use with Google Cloud Datastore to provide an entities concept

Install:
```shell script
pip install echo-datastore-entities
```
